import { CompatibleString } from 'storybook/internal/types';
import { BuilderOptions, StorybookConfigWebpack, TypescriptOptions } from '@storybook/builder-webpack5';
import { ReactOptions, StorybookConfig as StorybookConfig$1, TypescriptOptions as TypescriptOptions$1 } from '@storybook/preset-react-webpack';
import * as _NextImage from 'next/image';
import { NextRouter } from 'next/router';

type FrameworkName = CompatibleString<'@storybook/nextjs'>;
type BuilderName = CompatibleString<'@storybook/builder-webpack5'>;
type FrameworkOptions = ReactOptions & {
    nextConfigPath?: string;
    image?: Partial<_NextImage.ImageProps>;
    builder?: BuilderOptions;
};
type StorybookConfigFramework = {
    framework: FrameworkName | {
        name: FrameworkName;
        options: FrameworkOptions;
    };
    core?: StorybookConfig$1['core'] & {
        builder?: BuilderName | {
            name: BuilderName;
            options: BuilderOptions;
        };
    };
    typescript?: Partial<TypescriptOptions & TypescriptOptions$1> & StorybookConfig$1['typescript'];
};
/** The interface for Storybook configuration in `main.ts` files. */
type StorybookConfig = Omit<StorybookConfig$1, keyof StorybookConfigWebpack | keyof StorybookConfigFramework> & StorybookConfigWebpack & StorybookConfigFramework;
interface NextJsParameters {
    /**
     * Next.js framework configuration
     *
     * @see https://storybook.js.org/docs/get-started/frameworks/nextjs
     */
    nextjs?: {
        /**
         * Enable App Directory features If your story imports components that use next/navigation, you
         * need to set this parameter to true
         */
        appDirectory?: boolean;
        /**
         * Next.js navigation configuration when using `next/navigation`. Please note that it can only
         * be used in components/pages in the app directory.
         */
        navigation?: NextRouter;
        /** Next.js router configuration */
        router?: NextRouter;
    };
}

export { FrameworkOptions as F, NextJsParameters as N, StorybookConfig as S };
